@@ -1,4 +1,7 @@
 """
+DEPRECATD. THIS IS BEING MOVED TO KWCOCO FOR DEVELOPMENT AND EVENTUALLY WILL
+LIVE IN KWIMAGE.
+
 The classes in this file represent a tree of delayed operations.
 
 Proof of concept for delayed chainable transforms in Python.
@@ -388,7 +391,7 @@ class DelayedLoad(DelayedImageOperation):
             dsize = self.meta.get('dsize', None)
             if dsize is not None:
                 final = np.asarray(final)
-                final = kwimage.imresize(final, dsize=dsize)
+                final = kwimage.imresize(final, dsize=dsize, antialias=True)
             self.cache['final'] = final
 
         as_xarray = kwargs.get('as_xarray', False)
@@ -710,29 +713,6 @@ class DelayedWarp(DelayedImageOperation):
         >>> tf = np.array([[5.2, 0, 1.1], [0, 3.1, 2.2], [0, 0, 1]])
         >>> self = DelayedWarp(np.random.rand(3, 5, 13), tf, dsize=dsize)
         >>> self.finalize().shape
-
-    Example:
-        >>> # Test aliasing
-        >>> from ndsampler.delayed import *  # NOQA
-        >>> s = DelayedIdentity.demo('checkerboard')
-        >>> s = DelayedIdentity.demo()
-        >>> a = s.delayed_warp(Affine.scale(0.05), dsize='auto')
-        >>> b = s.delayed_warp(Affine.scale(3), dsize='auto')
-
-        >>> # xdoctest: +REQUIRES(--show)
-        >>> import kwplot
-        >>> kwplot.autompl()
-        >>> # It looks like downsampling linear and area is the same
-        >>> # Does warpAffine have no alias handling?
-        >>> pnum_ = kwplot.PlotNums(nRows=2, nCols=4)
-        >>> kwplot.imshow(a.finalize(interpolation='area'), pnum=pnum_(), title='warpAffine area')
-        >>> kwplot.imshow(a.finalize(interpolation='linear'), pnum=pnum_(), title='warpAffine linear')
-        >>> kwplot.imshow(a.finalize(interpolation='nearest'), pnum=pnum_(), title='warpAffine nearest')
-        >>> kwplot.imshow(a.finalize(interpolation='cubic'), pnum=pnum_(), title='warpAffine cubic')
-        >>> kwplot.imshow(kwimage.imresize(s.finalize(), dsize=a.dsize, interpolation='area'), pnum=pnum_(), title='resize area')
-        >>> kwplot.imshow(kwimage.imresize(s.finalize(), dsize=a.dsize, interpolation='linear'), pnum=pnum_(), title='resize linear')
-        >>> kwplot.imshow(kwimage.imresize(s.finalize(), dsize=a.dsize, interpolation='nearest'), pnum=pnum_(), title='resize nearest')
-        >>> kwplot.imshow(kwimage.imresize(s.finalize(), dsize=a.dsize, interpolation='cubic'), pnum=pnum_(), title='resize cubic')
     """
     def __init__(self, sub_data, transform=None, dsize=None):
         self.sub_data = sub_data
@@ -910,11 +890,34 @@ class DelayedWarp(DelayedImageOperation):
             >>> kwplot.imshow(final1, pnum=(1, 3, 2), fnum=1)
             >>> kwplot.imshow(final2, pnum=(1, 3, 3), fnum=1)
             >>> kwplot.show_if_requested()
+
+        Example:
+            >>> # Test aliasing
+            >>> from ndsampler.delayed import *  # NOQA
+            >>> s = DelayedIdentity.demo()
+            >>> s = DelayedIdentity.demo('checkerboard')
+            >>> a = s.delayed_warp(Affine.scale(0.05), dsize='auto')
+            >>> b = s.delayed_warp(Affine.scale(3), dsize='auto')
+
+            >>> # xdoctest: +REQUIRES(--show)
+            >>> import kwplot
+            >>> kwplot.autompl()
+            >>> # It looks like downsampling linear and area is the same
+            >>> # Does warpAffine have no alias handling?
+            >>> pnum_ = kwplot.PlotNums(nRows=2, nCols=4)
+            >>> kwplot.imshow(a.finalize(interpolation='area'), pnum=pnum_(), title='warpAffine area')
+            >>> kwplot.imshow(a.finalize(interpolation='linear'), pnum=pnum_(), title='warpAffine linear')
+            >>> kwplot.imshow(a.finalize(interpolation='nearest'), pnum=pnum_(), title='warpAffine nearest')
+            >>> kwplot.imshow(a.finalize(interpolation='nearest', antialias=False), pnum=pnum_(), title='warpAffine nearest AA=0')
+            >>> kwplot.imshow(kwimage.imresize(s.finalize(), dsize=a.dsize, interpolation='area'), pnum=pnum_(), title='resize area')
+            >>> kwplot.imshow(kwimage.imresize(s.finalize(), dsize=a.dsize, interpolation='linear'), pnum=pnum_(), title='resize linear')
+            >>> kwplot.imshow(kwimage.imresize(s.finalize(), dsize=a.dsize, interpolation='nearest'), pnum=pnum_(), title='resize nearest')
+            >>> kwplot.imshow(kwimage.imresize(s.finalize(), dsize=a.dsize, interpolation='cubic'), pnum=pnum_(), title='resize cubic')
         """
         # todo: needs to be extended for the case where the sub_data is a
         # nested chain of transforms.
-        import cv2
-        from kwimage import im_cv2
+        # import cv2
+        # from kwimage import im_cv2
         if dsize is None:
             dsize = self.dsize
         transform = Affine.coerce(transform) @ self.transform
@@ -932,33 +935,16 @@ class DelayedWarp(DelayedImageOperation):
         else:
             as_xarray = kwargs.get('as_xarray', False)
             # Leaf finalize
-            flags = im_cv2._coerce_interpolation(interpolation)
+            # flags = im_cv2._coerce_interpolation(interpolation)
             if dsize == (None, None):
                 dsize = None
             sub_data_ = np.asarray(sub_data)
-            # sub_data_ = sub_data_.astype(np.float32) / 255.
-            # print('flags = {!r}'.format(flags))
-            # print('sub_data_.dtype = {!r}'.format(sub_data_.dtype))
-
-            # TODO: should we blur the source if the determanent of M is less
-            # than 1? If so by how much
-            if kwargs.get('antialias', True) and interpolation != 'nearest':
-                factor = transform.det()
-                # [0:2, 0:2])
-                # Hacked in heuristic for antialiasing before a downsample
-                if factor < 0.99:
-                    k = int(1 / np.sqrt(factor) * 1.2)
-                    if k % 2 == 0:
-                        k += 1
-                    sigma = 0.3 * ((k - 1) * 0.5 - 1) + 0.8
-                    sigma = sigma ** 1.2
-                    sub_data_ = sub_data_.copy()
-                    sub_data_ = cv2.GaussianBlur(sub_data_, (k, k), sigma, sigma)
-
             M = np.asarray(transform)
-            final = cv2.warpAffine(sub_data_, M[0:2], dsize=dsize, flags=flags)
+            antialias = kwargs.get('antialias', True)
+            final = kwimage.warp_affine(sub_data_, M, dsize=dsize,
+                                        interpolation=interpolation,
+                                        antialias=antialias)
             # final = cv2.warpPerspective(sub_data_, M, dsize=dsize, flags=flags)
-            print(final.mean())
             # Ensure that the last dimension is channels
             final = kwarray.atleast_nd(final, 3, front=False)
             if as_xarray:
